package Catalyst::Controller::Rose;

our $VERSION = '0.02';

1;

__END__

=head1 NAME

Catalyst::Controller::Rose - RDBO and RHTMLO base classes for Catalyst

=head1 DESCRIPTION

Catalyst::Controller::Rose provides several base Controller classes
for creating CRUD-style Catalyst applications using Rose::DB::Object
and Rose::HTML::Objects.

This class is simply a placeholder for an overall VERSION of the
Catalyst::Controller::Rose namespace.

=head1 SEE ALSO

Catalyst::Model::RDBO

=head1 AUTHOR

Peter Karman <perl@peknet.com>

Thanks to Atomic Learning, Inc for sponsoring the development of this module.

=head1 LICENSE

This library is free software. You may redistribute it and/or modify it under
the same terms as Perl itself.

=cut

